
# Type: expresses


holds between an anatomical entity and gene or gene product that is expressed there

URI: [biolink:expresses](https://w3id.org/biolink/vocab/expresses)


## Domain and Range

[AnatomicalEntity](AnatomicalEntity.md) ->  <sub>0..*</sub> [GeneOrGeneProduct](GeneOrGeneProduct.md)

## Parents

 *  is_a: [related to](related_to.md)

## Children


## Used by

 * [AnatomicalEntity](AnatomicalEntity.md)
 * [Cell](Cell.md)
 * [CellularComponent](CellularComponent.md)
 * [GrossAnatomicalStructure](GrossAnatomicalStructure.md)

## Other properties

|  |  |  |
| --- | --- | --- |
| **Mappings:** | | RO:0002292 |
| **In Subsets:** | | translator_minimal |

